@@ -64,6 +64,9 @@
 #'   procedures that would try to consider all available parameters.
 #'   Default is \code{TRUE} (except for \code{untyped}, \code{function}, \code{character} and
 #'   \code{characterVector}) which means it is tunable.
+#' @param special.vals [\code{list()}]\cr
+#'   A list of special values the parameter can except which are outside of the defined range.
+#'   Default is an empty list.
 #' @return [\code{\link{Param}}].
 #' @name Param
 #' @rdname Param
@@ -75,7 +78,7 @@
 NULL
 
 makeParam = function(id, type, len, lower, upper, values, cnames, allow.inf = FALSE, default,
-  trafo = NULL, requires = NULL, tunable = TRUE) {
+  trafo = NULL, requires = NULL, tunable = TRUE, special.vals = list()) {
   assertString(id)
   #We cannot check default} for NULL or NA as this could be the default value!
   if (missing(default)) {
@@ -93,6 +96,7 @@ makeParam = function(id, type, len, lower, upper, values, cnames, allow.inf = FA
     requires = convertExpressionToCall(requires)
     assertClass(requires, "call")
   }
+  assertList(special.vals)
   p = makeS3Obj("Param",
     id = id,
     type = type,
@@ -106,7 +110,8 @@ makeParam = function(id, type, len, lower, upper, values, cnames, allow.inf = FA
     default = default,
     trafo = trafo,
     requires = requires,
-    tunable = tunable
+    tunable = tunable,
+    special.vals = special.vals
   )
   if (has.default && !isFeasible(p, default))
     stop(p$id, " : 'default' must be a feasible parameter setting.")
@@ -116,16 +121,40 @@ makeParam = function(id, type, len, lower, upper, values, cnames, allow.inf = FA
 getParPrintData = function(x, trafo = TRUE, used = TRUE, constr.clip = 40L) {
   g = function(n) collapse(sprintf("%.3g", n))
   if (isNumeric(x, include.int = TRUE)) {
-    constr = sprintf("%s to %s", g(x$lower), g(x$upper))
+    if (!is.expression(x$lower) && !is.expression(x$upper) &&
+      (length(unique(x$lower)) == 1L) && (length(unique(x$upper)) == 1L)) {
+      x$lower = unique(x$lower)
+      x$upper = unique(x$upper)
+    }
+    low = if (is.expression(x$lower))  as.character(x$lower) else g(x$lower)
+    upp = if (is.expression(x$upper)) as.character(x$upper) else g(x$upper)
+    constr = sprintf("%s to %s", low, upp)
   } else if (isDiscrete(x, include.logical = FALSE)) {
-    constr = clipString(collapse(names(x$values)), constr.clip)
-  } else {
+    vals = if (is.expression(x$values)) as.character(x$values) else collapse(names(x$values))
+    constr = clipString(vals, constr.clip)
+  } else
     constr = "-"
+  if (x$has.default) {
+    if (!is.expression(x$default)) {
+      def = x$default
+      def = paramValueToString(x, def)
+    } else
+      def = as.character(x$default)
+  } else {
+    def = "-"
+  }
+  if (isVector(x)) {
+    if (!is.expression(x$len))
+      len = x$len
+    else
+      len = as.character(x$len)
+  } else {
+    len = "-"
   }
   d = data.frame(
     Type = x$type,
-    len = ifelse(isVector(x), x$len, "-"),
-    Def = if (x$has.default) paramValueToString(x, x$default) else "-",
+    len = len,
+    Def = def,
     Constr = constr,
     Req = ifelse(is.null(x$requires), "-", "Y"),
     Tunable = x$tunable,
