@@ -186,9 +186,9 @@ test_that("requires chains work", {
     makeLogicalLearnerParam("a", default = FALSE),
     makeLogicalLearnerParam("b", default = FALSE, requires = quote(a == TRUE)),
     # FIXME: shouldn't need to make the chain explicit
-    makeLogicalLearnerParam("c", default = FALSE, requires = quote(b == TRUE && a == TRUE))
+    makeNumericLearnerParam("c", lower = 0, upper = 1, requires = quote(b == TRUE && a == TRUE))
   )
-  des = generateDesign(10, par.set = ps8)
+  des = generateDesign(4L, par.set = ps8, augment = 100L)
   vals = dfRowsToList(des, ps8)
   oks = sapply(vals, isFeasible, par = ps8)
   expect_true(all(oks))
@@ -221,3 +221,18 @@ test_that("removing duplicates", {
   expect_warning(res <- generateDesign(7L, ps))
   expect_true(nrow(res) <= 6L)
 })
+
+test_that("vector params and forbidden regions", {
+  # here we have a parameter set with a vector parameters
+  ps = makeParamSet(
+    makeNumericVectorParam(id = "x", len = 2, lower = 0, upper = 1),
+    makeDiscreteParam(id = "disc", values = letters[1:2]),
+    forbidden = expression(sum(x) > 1)
+  )
+
+  # the expression in 'forbidden' should not throw an error anymore
+  # See https://github.com/berndbischl/ParamHelpers/issues/51
+  res = generateDesign(100L, ps)
+  expect_equal(nrow(res), 100L)
+  expect_numeric(rowSums(res[,c("x1","x2")]), lower = 0, upper = 1)
+})
